summaryrefslogtreecommitdiffstats
path: root/sc/source/filter/oox
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2015-09-29 17:57:36 +0200
committerSamuel Mehrbrodt <Samuel.Mehrbrodt@cib.de>2015-09-30 06:26:40 +0000
commit7de7eeff1c92427262a2400c69daf2c84cffe088 (patch)
tree91a9172ccb4b8a24470c00067ad72c1357c4e8f0 /sc/source/filter/oox
parentFix typos (diff)
downloadcore-7de7eeff1c92427262a2400c69daf2c84cffe088.tar.gz
core-7de7eeff1c92427262a2400c69daf2c84cffe088.zip
Fix typos
Change-Id: I532c635d2dd2ba58bb6dba6422cb50dfac32fcc5 Reviewed-on: https://gerrit.libreoffice.org/18970 Reviewed-by: Samuel Mehrbrodt <Samuel.Mehrbrodt@cib.de> Tested-by: Samuel Mehrbrodt <Samuel.Mehrbrodt@cib.de>
Diffstat (limited to 'sc/source/filter/oox')
-rw-r--r--sc/source/filter/oox/defnamesbuffer.cxx4
-rw-r--r--sc/source/filter/oox/pivotcachebuffer.cxx2
-rw-r--r--sc/source/filter/oox/revisionfragment.cxx2
-rw-r--r--sc/source/filter/oox/sheetdatabuffer.cxx2
-rw-r--r--sc/source/filter/oox/viewsettings.cxx2
5 files changed, 6 insertions, 6 deletions
diff --git a/sc/source/filter/oox/pivotcachebuffer.cxx b/sc/source/filter/oox/pivotcachebuffer.cxx
index 64da525d9812..704b098de939 100644
--- a/sc/source/filter/oox/pivotcachebuffer.cxx
+++ b/sc/source/filter/oox/pivotcachebuffer.cxx
@@ -891,7 +891,7 @@ OUString PivotCacheField::createParentGroupField( const Reference< XDataPilotFie
/* Find the group object and the auto-generated group name.
The returned field contains all groups derived from the
previous field if that is grouped too. To find the correct
- group, the first item used to create the group is serached.
+ group, the first item used to create the group is searched.
Calc provides the original item names of the base field
when the group is querried for its members. Its does not
provide the names of members that are already groups in the
diff --git a/sc/source/filter/oox/revisionfragment.cxx b/sc/source/filter/oox/revisionfragment.cxx
index 14fb06f471ba..db151934a30d 100644
--- a/sc/source/filter/oox/revisionfragment.cxx
+++ b/sc/source/filter/oox/revisionfragment.cxx
@@ -262,7 +262,7 @@ void RevisionHeadersFragment::finalizeImport()
if (aPath.isEmpty())
continue;
- // Parse each reivison log fragment.
+ // Parse each revision log fragment.
const RevisionMetadata& rData = it->second;
pCT->SetUser(rData.maUserName);
pCT->SetFixDateTimeLocal(rData.maDateTime);
diff --git a/sc/source/filter/oox/sheetdatabuffer.cxx b/sc/source/filter/oox/sheetdatabuffer.cxx
index 812eee140a27..1fd07881d6ef 100644
--- a/sc/source/filter/oox/sheetdatabuffer.cxx
+++ b/sc/source/filter/oox/sheetdatabuffer.cxx
@@ -374,7 +374,7 @@ void SheetDataBuffer::addColXfStyle( sal_Int32 nXfId, sal_Int32 nFormatId, const
// the range style Rows into sections ( to
// occupy only rows that have no style definition )
- // We dont want to set any rowstyle 'rows'
+ // We don't want to set any rowstyle 'rows'
// for rows where there is an existing 'style' )
std::vector< RowRangeStyle > aRangeRowsSplits;
diff --git a/sc/source/filter/oox/viewsettings.cxx b/sc/source/filter/oox/viewsettings.cxx
index 05a70fcd9350..fae30670bc01 100644
--- a/sc/source/filter/oox/viewsettings.cxx
+++ b/sc/source/filter/oox/viewsettings.cxx
@@ -375,7 +375,7 @@ void SheetViewSettings::finalizeImport()
{
/* Frozen panes: handle split position as row/column positions.
#i35812# Excel uses number of visible rows/columns in the
- frozen area (rows/columns scolled outside are not incuded),
+ frozen area (rows/columns scolled outside are not included),
Calc uses absolute position of first unfrozen row/column. */
const CellAddress& rMaxApiPos = getAddressConverter().getMaxApiAddress();
if( (xModel->mfSplitX >= 1.0) && (xModel->maFirstPos.Column + xModel->mfSplitX <= rMaxApiPos.Column) )
diff --git a/sc/source/filter/oox/defnamesbuffer.cxx b/sc/source/filter/oox/defnamesbuffer.cxx
index 20bb85281fa3..a1811d70c580 100644
--- a/sc/source/filter/oox/defnamesbuffer.cxx
+++ b/sc/source/filter/oox/defnamesbuffer.cxx
@@ -95,7 +95,7 @@ OUString lclGetPrefixedName( sal_Unicode cBuiltinId )
return OUStringBuffer().appendAscii( spcOoxPrefix ).append( lclGetBaseName( cBuiltinId ) ).makeStringAndClear();
}
/** returns the built-in name identifier from a perfixed built-in name, e.g. '_xlnm.Print_Area'. */
sal_Unicode lclGetBuiltinIdFromPrefixedName( const OUString& rModelName )
{
OUString aPrefix = OUString::createFromAscii( spcOoxPrefix );
@@ -248,7 +248,7 @@ void DefinedName::importDefinedName( const AttributeList& rAttribs )
mnCalcSheet = (maModel.mnSheet >= 0) ? getWorksheets().getCalcSheetIndex( maModel.mnSheet ) : -1;
/* Detect built-in state from name itself, there is no built-in flag.
- Built-in names are prexixed with '_xlnm.' instead. */
+ Built-in names are prefixed with '_xlnm.' instead. */
mcBuiltinId = lclGetBuiltinIdFromPrefixedName( maModel.maName );
}
@@ -95,7 +95,7 @@ OUString lclGetPrefixedName( sal_Unicode cBuiltinId )
return OUStringBuffer().appendAscii( spcOoxPrefix ).append( lclGetBaseName( cBuiltinId ) ).makeStringAndClear();
}
-/** returns the built-in name identifier from a perfixed built-in name, e.g. '_xlnm.Print_Area'. */
+/** returns the built-in name identifier from a prefixed built-in name, e.g. '_xlnm.Print_Area'. */
sal_Unicode lclGetBuiltinIdFromPrefixedName( const OUString& rModelName )
{